==> qtjambi-webenginewidgets-5.15.17-sources.jar: io/qt/webengine/widgets/QWebEngineFullScreenRequest.java <==
package io.qt.webengine.widgets;

import io.qt.*;


/**
 * <p>Java wrapper for Qt class <code>QWebEngineFullScreenRequest</code></p>
 */
public final class QWebEngineFullScreenRequest extends QtObject
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QWebEngineFullScreenRequest.class);
    
    
    /**
     * <p>See <code>QWebEngineFullScreenRequest::<wbr>accept()</code></p>
     */
    public final void accept(){
        accept_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    private native void accept_native(long __this__nativeId);
    
    /**
     * <p>See <code>QWebEngineFullScreenRequest::<wbr>origin()const</code></p>
     */
    @QtPropertyReader(name="origin")
    @QtPropertyConstant
    @QtUninvokable
    public final io.qt.core.@NonNull QUrl origin(){
        return origin_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QUrl origin_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>QWebEngineFullScreenRequest::<wbr>reject()</code></p>
     */
    public final void reject(){
        reject_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    private native void reject_native(long __this__nativeId);
    
    /**
     * <p>See <code>QWebEngineFullScreenRequest::<wbr>toggleOn()const</code></p>
     */
    @QtPropertyReader(name="toggleOn")
    @QtPropertyConstant
    @QtUninvokable
    public final boolean toggleOn(){
        return toggleOn_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean toggleOn_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QWebEngineFullScreenRequest(QPrivateConstructor p) { super(p); } 
    
    
    /**
     * <p>Creates and returns a copy of this object.</p>
     */
    @QtUninvokable
    @Override
    public QWebEngineFullScreenRequest clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private static native QWebEngineFullScreenRequest clone_native(long __this_nativeId);
    
    /**
     * <p>Kotlin property getter. In Java use {@link #origin()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final io.qt.core.@NonNull QUrl getOrigin() {
        return origin();
    }
    
    /**
     * <p>Kotlin property getter. In Java use {@link #toggleOn()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final boolean getToggleOn() {
        return toggleOn();
    }
}

==> qtjambi-webenginewidgets-5.15.18-sources.jar: io/qt/webengine/widgets/QWebEngineFullScreenRequest.java <==
package io.qt.webengine.widgets;

import io.qt.*;


/**
 * <p>Java wrapper for Qt class <code>QWebEngineFullScreenRequest</code></p>
 */
public final class QWebEngineFullScreenRequest extends QtObject
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QWebEngineFullScreenRequest.class);
    
    
    /**
     * <p>See <code>QWebEngineFullScreenRequest::<wbr/>accept()</code></p>
     */
    public final void accept(){
        accept_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    private native void accept_native(long __this__nativeId);
    
    /**
     * <p>See <code>QWebEngineFullScreenRequest::<wbr/>origin()const</code></p>
     */
    @QtPropertyReader(name="origin")
    @QtPropertyConstant
    @QtUninvokable
    public final io.qt.core.@NonNull QUrl origin(){
        return origin_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QUrl origin_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>QWebEngineFullScreenRequest::<wbr/>reject()</code></p>
     */
    public final void reject(){
        reject_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    private native void reject_native(long __this__nativeId);
    
    /**
     * <p>See <code>QWebEngineFullScreenRequest::<wbr/>toggleOn()const</code></p>
     */
    @QtPropertyReader(name="toggleOn")
    @QtPropertyConstant
    @QtUninvokable
    public final boolean toggleOn(){
        return toggleOn_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean toggleOn_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QWebEngineFullScreenRequest(QPrivateConstructor p) { super(p); } 
    
    
    /**
     * <p>Creates and returns a copy of this object.</p>
     */
    @QtUninvokable
    @Override
    public QWebEngineFullScreenRequest clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private static native QWebEngineFullScreenRequest clone_native(long __this_nativeId);
    
    /**
     * @hidden
     * <p>Kotlin property getter. In Java use {@link #origin()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final io.qt.core.@NonNull QUrl getOrigin() {
        return origin();
    }
    
    /**
     * @hidden
     * <p>Kotlin property getter. In Java use {@link #toggleOn()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final boolean getToggleOn() {
        return toggleOn();
    }
}
